@@ -106,6 +106,11 @@ def getspace(string):
     global java_space
     string += "   "*java_space
     return string
+def getonlyspace():
+    global java_space
+    string = ''
+    string += "   "*java_space
+    return string
 def make():
     Strin = ''
     global addition_list
@@ -193,8 +198,11 @@ def make():
                     python_space += 1
                     java_space += 1
             elif m == 'while_event':
-                if javacode.__contains__("Bukkit.getPluginManager().registerEvents(this,this)"):
-                    javacode = javacode.replace('public void onDisable(){\n', 'public void onDisable(){\nBukkit.getPluginManager().registerEvents(this,this);')
+                if not javacode.__contains__("Bukkit.getPluginManager().registerEvents(this,this)"):
+                    addition_list.append("org.bukkit.Bukkit")
+                    javacode = getspace(javacode)
+                    r = getonlyspace()
+                    javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'Bukkit.getPluginManager().registerEvents(this,this);\n')
                 global test_value
                 test_value += 1
                 name = 'test'+str(test_value)
